import type { ProviderRange } from './completion-providers';
export declare class Completion {
    label: string;
    detail: string;
    sortText: string;
    insertText: string | Snippet;
    range: ProviderRange;
    additionalCompletions: boolean;
    triggerSignature: boolean;
    constructor(label: string, detail: string, sortText: string, insertText: string | Snippet, range: ProviderRange, additionalCompletions?: boolean, triggerSignature?: boolean);
}
export declare class Snippet {
    source: string;
    constructor(source: string);
}
export declare const importDirectives: {
    readonly from: "-st-from";
    readonly default: "-st-default";
    readonly named: "-st-named";
};
export declare const rulesetDirectives: {
    readonly extends: "-st-extends";
    readonly mixin: "-st-mixin";
    readonly states: "-st-states";
};
export declare const topLevelDirectives: {
    readonly root: ".root";
    readonly namespace: "@st-namespace";
    readonly customSelector: "@custom-selector :--";
    readonly vars: ":vars";
    readonly import: ":import";
    readonly stScope: "@st-scope";
    readonly stImport: "@st-import";
    readonly stGlobalCustomProperty: "@st-global-custom-property";
};
export declare function importInternalDirective(type: keyof typeof importDirectives, rng: ProviderRange): Completion;
export declare function rulesetInternalDirective(type: keyof typeof rulesetDirectives, rng: ProviderRange): Completion;
export declare function topLevelDirective(type: keyof typeof topLevelDirectives, rng: ProviderRange): Completion;
export declare function valueDirective(rng: ProviderRange): Completion;
export declare function globalCompletion(rng: ProviderRange): Completion;
export declare function classCompletion(className: string, rng: ProviderRange, removeDot?: boolean): Completion;
export declare function extendCompletion(symbolName: string, from: string, rng: ProviderRange): Completion;
export declare function namedCompletion(symbolName: string, rng: ProviderRange, from: string, value?: string): Completion;
export declare function cssMixinCompletion(symbolName: string, rng: ProviderRange, from: string): Completion;
export declare function codeMixinCompletion(symbolName: string, rng: ProviderRange, from: string): Completion;
export declare function formatterCompletion(symbolName: string, rng: ProviderRange, from: string): Completion;
export declare function pseudoElementCompletion(elementName: string, from: string, rng: ProviderRange): Completion;
export declare function stateTypeCompletion(type: string, from: string, rng: ProviderRange): Completion;
export declare function stateCompletion(stateName: string, from: string, rng: ProviderRange, type: string | null, hasParam?: boolean): Completion;
export declare function stateEnumCompletion(option: string, from: string, rng: ProviderRange): Completion;
export declare function valueCompletion(name: string, from: string, value: string, rng: ProviderRange): Completion;
//# sourceMappingURL=completion-types.d.ts.map