"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createRange = exports.createDiagnosis = void 0;
const vscode_languageserver_1 = require("vscode-languageserver");
function createDiagnosis(content, version, filePath, stylable, cssService) {
    if (!filePath.endsWith('.st.css')) {
        return [];
    }
    const meta = stylable.fileProcessor.processContent(content, filePath);
    try {
        stylable.transform(meta);
    }
    catch {
        /*TODO: report this failure to transform */
    }
    const cleanDoc = cssService.createSanitizedDocument(meta.sourceAst, filePath, version);
    return meta.diagnostics.reports
        .concat(meta.transformDiagnostics ? meta.transformDiagnostics.reports : [])
        .map(reportToDiagnostic)
        .concat(cssService.getDiagnostics(cleanDoc, meta));
    // stylable diagnostic to protocol diagnostic
    function reportToDiagnostic(report) {
        const severity = report.severity === 'error' ? 1 : 2;
        const range = createRange(report);
        // todo: incorporate diagnostics code in v5
        return vscode_languageserver_1.Diagnostic.create(range, report.message, severity, undefined, 'stylable');
    }
}
exports.createDiagnosis = createDiagnosis;
function createRange(report) {
    const source = report.node.source;
    const start = { line: 0, character: 0 };
    const end = { line: 0, character: 0 };
    if (report.word && source) {
        const lines = source.input.css.split('\n');
        const searchStart = source.start.line - 1;
        const searchEnd = source.end.line - 1;
        for (let i = searchStart; i <= searchEnd; ++i) {
            const wordIndex = lines[i].indexOf(report.word);
            if (~wordIndex) {
                start.line = i;
                start.character = wordIndex;
                end.line = i;
                end.character = wordIndex + report.word.length;
                break;
            }
        }
    }
    else if (source) {
        start.line = source.start.line - 1;
        start.character = source.start.column - 1;
        end.line = source.end.line - 1;
        end.character = source.end.column;
    }
    return vscode_languageserver_1.Range.create(start, end);
}
exports.createRange = createRange;
//# sourceMappingURL=diagnosis.js.map